![PyPI - Python Version](https://img.shields.io/pypi/pyversions/pymortafix)
[![PyPI](https://img.shields.io/pypi/v/pymortafix?color=red)](https://pypi.org/project/pymortafix/)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
![GitHub](https://img.shields.io/github/license/mortafix/PyMortafix)

# Setup
You can find the package, [here](https://pypi.org/project/pymortafix/).
```
pip3 install pymortafix
```
